@@ -24,26 +24,26 @@
 ActivityHandler::ActivityHandler(GlobalObject *globalObject,
                                  QObject *parent) : QObject(parent)
 {
-    this->globalObj = globalObject;
+    m_globalObject = globalObject;
 
-    this->xmppClient = this->globalObj->getXmppClient();
-    this->mucManager = this->globalObj->getMucManager();
-    this->varParser = this->globalObj->getVariableParser();
+    m_xmppClient = m_globalObject->getXmppClient();
+    m_mucManager = m_globalObject->getMucManager();
+    m_variableParser = m_globalObject->getVariableParser();
 
 
     // Start main timer, ticking once a minute, to check if an activity needs to be started
-    this->mainTimer = new QTimer(this);
-    mainTimer->setInterval(60000); // 60 seconds
-    connect(mainTimer, SIGNAL(timeout()),
-            this, SLOT(onMainTimerTick()));
-    mainTimer->start();
+    m_mainTimer = new QTimer(this);
+    m_mainTimer->setInterval(60000); // 60 seconds
+    connect(m_mainTimer, &QTimer::timeout,
+            this, &ActivityHandler::onMainTimerTick);
+    m_mainTimer->start();
 
 
     // Activity-specific timer; signals the end of the activity
-    this->currentActivityTimer = new QTimer(this);
-    currentActivityTimer->setSingleShot(true);
-    connect(currentActivityTimer, SIGNAL(timeout()),
-            this, SLOT(activityFinished()));
+    m_currentActivityTimer = new QTimer(this);
+    m_currentActivityTimer->setSingleShot(true);
+    connect(m_currentActivityTimer, &QTimer::timeout,
+            this, &ActivityHandler::activityFinished);
 
     qDebug() << "ActivityHandler created";
 }
@@ -57,7 +57,7 @@ ActivityHandler::~ActivityHandler()
 
 void ActivityHandler::setActivityData(QVariantList dataList)
 {
-    this->activityDataList = dataList;
+    m_activityDataList = dataList;
 }
 
 
@@ -104,24 +104,24 @@ void ActivityHandler::onMainTimerTick()
     if (timeNow.hour() == 0 && timeNow.minute() == 0) // FIXME: ensure it's not skipped
     {
         qDebug() << "--AH DEBUG-- Midnight! Resetting DoneToday values";
-        this->doneToday.clear();
+        m_doneToday.clear();
     }
 
-    if (!activityInProgress.isEmpty())
+    if (!m_activityInProgress.isEmpty())
     {
         return;
     }
 
 
-    foreach (QVariant mapVariant, this->activityDataList)
+    foreach (QVariant mapVariant, m_activityDataList)
     {
         QVariantMap map = mapVariant.toMap();
 
-        QString activityName = map.value("name").toString();
+        const QString activityName = map.value("name").toString();
 
         bool shouldDoIt = true; // Until proven guilty
 
-        int timesDoneToday = this->doneToday.value(activityName).toInt();
+        const int timesDoneToday = m_doneToday.value(activityName).toInt();
         if (timesDoneToday >= map.value("timesPerDay").toInt())
         {
             shouldDoIt = false;
@@ -148,11 +148,11 @@ void ActivityHandler::onMainTimerTick()
 
         if (shouldDoIt) // It passed all the trials, and survived!
         {
-            this->activityInProgress = activityName;
-            this->doneToday.insert(activityName, timesDoneToday + 1);
+            m_activityInProgress = activityName;
+            m_doneToday.insert(activityName, timesDoneToday + 1);
 
-            int duration = Helpers::randomBetween(map.value("minDuration").toInt(),
-                                                  map.value("maxDuration").toInt());
+            const int duration = Helpers::randomBetween(map.value("minDuration").toInt(),
+                                                        map.value("maxDuration").toInt());
 
             QTime durationTime;
             durationTime.setHMS(0, 0, 0); // Qt 5.x requires this initialization
@@ -176,47 +176,50 @@ void ActivityHandler::onMainTimerTick()
                                          durationTime.minute()));
             }
 
+                                         // Up to 9 extra seconds, randomly
+            const int extraMiliseconds = Helpers::randomBetween(0, 9000);
 
-            this->currentActivityTimer->start(duration * 60000); // mins to msecs
+            m_currentActivityTimer->start(duration * 60000    // Mins to msecs
+                                          + extraMiliseconds);
 
 
             QTime endTime = timeNow.addSecs(duration * 60);
 
-            this->globalObj->addToLog(tr("Starting activity %1, which "
-                                         "will end at %2.")
-                                      .arg("'" + activityInProgress + "'")
-                                      .arg(endTime.toString(Qt::SystemLocaleShortDate))
-                                      + " [" + durationString + "]");
+            m_globalObject->addToLog(tr("Starting activity %1, which "
+                                        "will end at %2.")
+                                     .arg("'" + m_activityInProgress + "'")
+                                     .arg(endTime.toString(Qt::SystemLocaleShortDate))
+                                     + " [" + durationString + "]");
 
 
             QString timeRange = timeNow.toString(Qt::SystemLocaleShortDate)
-                                + " ~ "
+                                + QStringLiteral(" ~ ")
                                 + endTime.toString(Qt::SystemLocaleShortDate);
 
-            this->globalObj->notifyActivityChange(activityInProgress, timeRange);
+            m_globalObject->notifyActivityChange(m_activityInProgress, timeRange);
 
 
             // Status type and message
-            QXmppPresence presence = this->xmppClient->clientPresence();
-            this->oldStatusType = presence.availableStatusType();
-            this->oldStatusMessage = presence.statusText();
+            QXmppPresence presence = m_xmppClient->clientPresence();
+            m_oldStatusType = presence.availableStatusType();
+            m_oldStatusMessage = presence.statusText();
 
             presence.setAvailableStatusType(this->presenceFromIndex(map.value("statusType")
                                                                         .toInt()));
 
             QString statusMsg = Helpers::randomString(map.value("statusMessages")
                                                          .toStringList());
-            statusMsg = this->varParser->getParsed(statusMsg);
+            statusMsg = m_variableParser->getParsed(statusMsg);
             presence.setStatusText(statusMsg);
 
 
-            this->messagesAfter = map.value("msgAfter").toStringList();
+            m_messagesAfter = map.value("msgAfter").toStringList();
 
 
-            if (this->globalObj->connectedToServer())
+            if (m_globalObject->connectedToServer())
             {
                 // Send the new presence
-                this->xmppClient->setClientPresence(presence);
+                m_xmppClient->setClientPresence(presence);
 
 
                 // Send messages to configured recipients about the activity
@@ -225,16 +228,16 @@ void ActivityHandler::onMainTimerTick()
                 const int msgToRooms = map.value("msgToRooms").toInt();
                 if (msgToRooms == 0)       // All rooms
                 {
-                    m_allRecipientJids = this->globalObj->getJoinedRooms();
+                    m_allRecipientJids = m_globalObject->getJoinedRooms();
                 }
                 else if (msgToRooms == 1)  // Several rooms
                 {
-                    m_allRecipientJids = Helpers::someStrings(globalObj->getJoinedRooms(),
+                    m_allRecipientJids = Helpers::someStrings(m_globalObject->getJoinedRooms(),
                                                               50);
                 }
                 else if (msgToRooms == 2)  // A few rooms
                 {
-                    m_allRecipientJids = Helpers::someStrings(globalObj->getJoinedRooms(),
+                    m_allRecipientJids = Helpers::someStrings(m_globalObject->getJoinedRooms(),
                                                               20);
                 }
 
@@ -253,16 +256,16 @@ void ActivityHandler::onMainTimerTick()
                 foreach (QString recipient, m_allRecipientJids)
                 {
                     msgBefore = Helpers::randomString(messagesBefore);
-                    msgBefore = this->varParser->getParsed(msgBefore);
+                    msgBefore = m_variableParser->getParsed(msgBefore);
 
-                    if (msgBefore != "*") // TMP FIXME?
+                    if (msgBefore != QStringLiteral("*")) // TMP FIXME?
                     {
-                        this->globalObj->sendMessageToJid(recipient, msgBefore);
+                        m_globalObject->sendMessageToJid(recipient, msgBefore);
                     }
                 }
             }
 
-            this->globalObj->notifyStatusChange(presence);
+            m_globalObject->notifyStatusChange(presence);
 
 
             break;
@@ -273,40 +276,40 @@ void ActivityHandler::onMainTimerTick()
 
 void ActivityHandler::activityFinished()
 {
-    this->globalObj->addToLog(tr("Activity ended: %1.").arg(activityInProgress));
+    m_globalObject->addToLog(tr("Activity ended: %1.").arg(m_activityInProgress));
 
-    activityInProgress.clear();
-    this->globalObj->notifyActivityChange("[ " + tr("None",
-                                                    "Regarding an activity")
-                                          + " ]",
-                                          ""); // No duration
+    m_activityInProgress.clear();
+    m_globalObject->notifyActivityChange("[ " + tr("None",
+                                                   "Regarding an activity")
+                                         + " ]",
+                                         QString()); // No duration
 
-    QXmppPresence presence = this->xmppClient->clientPresence();
-    presence.setAvailableStatusType(this->oldStatusType);
-    presence.setStatusText(this->oldStatusMessage);
+    QXmppPresence presence = m_xmppClient->clientPresence();
+    presence.setAvailableStatusType(m_oldStatusType);
+    presence.setStatusText(m_oldStatusMessage);
 
-    if (this->globalObj->connectedToServer())
+    if (m_globalObject->connectedToServer())
     {
-        this->xmppClient->setClientPresence(presence);
+        m_xmppClient->setClientPresence(presence);
 
         // Send messages to configured recipients, about the end of the activity
         QString msgAfter;
         foreach (QString recipient, m_allRecipientJids)
         {
-            msgAfter = Helpers::randomString(this->messagesAfter);
-            msgAfter = this->varParser->getParsed(msgAfter);
+            msgAfter = Helpers::randomString(m_messagesAfter);
+            msgAfter = m_variableParser->getParsed(msgAfter);
 
-            if (msgAfter != "*")  // TMP FIXME?
+            if (msgAfter != QStringLiteral("*"))  // TMP FIXME?
             {
-                this->globalObj->sendMessageToJid(recipient, msgAfter);
+                m_globalObject->sendMessageToJid(recipient, msgAfter);
             }
         }
     }
 
-    this->globalObj->notifyStatusChange(presence);
+    m_globalObject->notifyStatusChange(presence);
 
     // Cleanup
     m_allRecipientJids.clear();
-    this->messagesAfter.clear();
+    m_messagesAfter.clear();
 }
 
