@@ -59,27 +59,27 @@ public slots:
 
 
 private:
-    QXmppClient *xmppClient;
-    QXmppMucManager *mucManager;
+    QXmppClient *m_xmppClient;
+    QXmppMucManager *m_mucManager;
 
-    QVariantList activityDataList;
+    QVariantList m_activityDataList;
 
-    QTimer *mainTimer;
-    QTimer *currentActivityTimer;
+    QTimer *m_mainTimer;
+    QTimer *m_currentActivityTimer;
 
 
-    QVariantMap doneToday;
-    QString activityInProgress;
+    QVariantMap m_doneToday;
+    QString m_activityInProgress;
 
     QStringList m_allRecipientJids;
-    QStringList messagesAfter;
+    QStringList m_messagesAfter;
 
-    QXmppPresence::AvailableStatusType oldStatusType;
-    QString oldStatusMessage;
+    QXmppPresence::AvailableStatusType m_oldStatusType;
+    QString m_oldStatusMessage;
 
 
-    GlobalObject *globalObj;
-    VariableParser *varParser;
+    GlobalObject *m_globalObject;
+    VariableParser *m_variableParser;
 };
 
 #endif // ACTIVITYHANDLER_H
