@@ -51,7 +51,7 @@ class ActivityModule : public QWidget
     Q_OBJECT
 
 public:
-    explicit ActivityModule(ActivityHandler *handler,
+    explicit ActivityModule(ActivityHandler *activityHandler,
                             GlobalObject *globalObject,
                             QWidget *parent = 0);
     ~ActivityModule();
@@ -78,65 +78,65 @@ public slots:
 
 
 private:
-    QHBoxLayout *mainLayout;
+    QHBoxLayout *m_mainLayout;
 
-    QVBoxLayout *leftLayout;
-    QPushButton *syncActivitiesButton;
-    QListWidget *activityListWidget;
-    QPushButton *addActivityButton;
-    QPushButton *removeActivityButton;
+    QVBoxLayout *m_leftLayout;
+    QPushButton *m_syncActivitiesButton;
+    QListWidget *m_activityListWidget;
+    QPushButton *m_addActivityButton;
+    QPushButton *m_removeActivityButton;
 
 
-    QScrollArea *rightScrollArea;
-    QWidget *rightWidget;
-    QVBoxLayout *rightLayout;
+    QScrollArea *m_rightScrollArea;
+    QWidget *m_rightWidget;
+    QVBoxLayout *m_rightLayout;
     QFormLayout *formLayout;    
 
-    QLineEdit *nameLineEdit;
+    QLineEdit *m_nameLineEdit;
 
-    QSpinBox *timesPerDaySpinbox;
-    QSpinBox *probabilitySpinbox;
+    QSpinBox *m_timesPerDaySpinbox;
+    QSpinBox *m_probabilitySpinbox;
 
-    QHBoxLayout *timeLayout;
-    QTimeEdit *minTimeEdit;
-    QTimeEdit *maxTimeEdit;
+    QHBoxLayout *m_timeLayout;
+    QTimeEdit *m_minTimeEdit;
+    QTimeEdit *m_maxTimeEdit;
 
-    QHBoxLayout *dateLayout;
-    QDateEdit *minDateEdit;
-    QDateEdit *maxDateEdit;
+    QHBoxLayout *m_dateLayout;
+    QDateEdit *m_minDateEdit;
+    QDateEdit *m_maxDateEdit;
 
-    QHBoxLayout *durationLayout;
-    QSpinBox *minDurationSpinbox;
-    QSpinBox *maxDurationSpinbox;
+    QHBoxLayout *m_durationLayout;
+    QSpinBox *m_minDurationSpinbox;
+    QSpinBox *m_maxDurationSpinbox;
 
-    QComboBox *statusTypeCombobox;
-    StringListWidget *statusMessagesListWidget;
+    QComboBox *m_statusTypeCombobox;
+    StringListWidget *m_statusMessagesListWidget;
 
-    QSpinBox *availabilitySpinbox;
+    QSpinBox *m_availabilitySpinbox;
 
-    QHBoxLayout *reactionLayout;
-    QSpinBox *minReactionSpinbox;
-    QSpinBox *maxReactionSpinbox;
+    QHBoxLayout *m_reactionLayout;
+    QSpinBox *m_minReactionSpinbox;
+    QSpinBox *m_maxReactionSpinbox;
 
-    StringListWidget *descriptionListWidget;
+    StringListWidget *m_descriptionListWidget;
 
-    StringListWidget *msgBeforeListWidget;
-    StringListWidget *msgAfterListWidget;
+    StringListWidget *m_msgBeforeListWidget;
+    StringListWidget *m_msgAfterListWidget;
 
-    QVBoxLayout *msgRecipientsLayout;
-    QHBoxLayout *recipientsTopLayout;
-    QComboBox *msgToRoomsCombobox;
-    QCheckBox *msgToActiveChatsCheckbox;
-    QHBoxLayout *recipientsBottomLayout;
-    QLabel *specificJidsText;
-    QLineEdit *specificJidsLineEdit;    
+    QVBoxLayout *m_msgRecipientsLayout;
+    QHBoxLayout *m_recipientsTopLayout;
+    QComboBox *m_msgToRoomsCombobox;
+    QCheckBox *m_msgToActiveChatsCheckbox;
+    QHBoxLayout *m_recipientsBottomLayout;
+    QLabel *m_specificJidsText;
+    QLineEdit *m_specificJidsLineEdit;
 
-    QPushButton *saveActivityButton;
+    QPushButton *m_saveActivityButton;
 
 
-    DataFile *dataFile;
-    ActivityHandler *activityHandler;
-    GlobalObject *globalObj;
+    DataFile *m_dataFile;
+    ActivityHandler *m_activityHandler;
+    GlobalObject *m_globalObject;
 };
 
 #endif // ACTIVITYMODULE_H
