@@ -43,7 +43,7 @@ class ChatWidget : public QWidget
     Q_OBJECT
 
 public:
-    explicit ChatWidget(GlobalObject *globalObject, QWidget *parent = 0);
+    explicit ChatWidget(GlobalObject *globalObject, QWidget *parent = nullptr);
     ~ChatWidget();
 
     void setRoom(QXmppMucRoom *room);
@@ -74,10 +74,10 @@ public slots:
 
     void onParticipantJoined(QString nickname);
     void onParticipantLeft(QString nickname);
-    void onKicked(QString jid, QString reason);
 
     void onJoined();
     void onLeft();
+    void onKicked(QString jid, QString reason);
 
 
 protected:
@@ -91,6 +91,7 @@ private:
     QLineEdit *messageLineEdit;
 
     bool isMuc;
+    QString m_kickedFromMucMessage;
     QXmppMucRoom *muc;
 
     QString chatTitle;
