@@ -33,7 +33,7 @@ CommandHandler::CommandHandler(GlobalObject *globalObject,
 
     // Give seed based on current time to random number generator
     uint randomSeed;
-    randomSeed = (QTime::currentTime().hour())
+    randomSeed = QTime::currentTime().hour()
                + (QTime::currentTime().minute() * 4)
                + (QTime::currentTime().second() * 5)
                + (QTime::currentTime().msec() * 6);
@@ -86,9 +86,13 @@ void CommandHandler::processCommand(QXmppMessage message)
                                      .arg(message.body()));
 
             commandReply = this->parseCommand(message.body(),
-                                              userAccessLevel);
+                                              userAccessLevel,
+                                              fromNick);
             const QString reply = commandReply.value("replyString").toString();
-            bool privateReply = commandReply.value("privateReply").toBool();
+            const bool privateReply = commandReply.value("privateReply")
+                                                  .toBool();
+            const bool hasReplyPattern = commandReply.value("haveReplyPattern")
+                                                     .toBool();
             if (!reply.isEmpty())
             {
                 if (privateReply)
@@ -97,7 +101,15 @@ void CommandHandler::processCommand(QXmppMessage message)
                 }
                 else
                 {
-                    room->sendMessage(QString("%1: %2").arg(fromNick).arg(reply));
+                    if (hasReplyPattern)
+                    {
+                        room->sendMessage(reply);
+                    }
+                    else // No custom reply pattern, so we use "Nick: message"
+                    {
+                        room->sendMessage(QString("%1: %2").arg(fromNick)
+                                                           .arg(reply));
+                    }
                 }
             }
         }
@@ -110,8 +122,12 @@ void CommandHandler::processCommand(QXmppMessage message)
 
         // TODO: handle per-user flood
 
+        // Get the username part of the JID as nickname
+        const QString niceNick = bareFrom.split("@").takeFirst();
+
         commandReply = this->parseCommand(message.body(),
-                                          userAccessLevel);
+                                          userAccessLevel,
+                                          niceNick);
         const QString reply = commandReply.value("replyString").toString();
         if (!reply.isEmpty())
         {
@@ -126,7 +142,8 @@ void CommandHandler::processCommand(QXmppMessage message)
  * and other relevant data
  *
  */
-QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
+QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
+                                         QString callingUser)
 {
     // Remove prefix
     commandString.remove(0, m_globalObject->getCommandPrefix().length());
@@ -159,7 +176,7 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
         }
         else
         {
-            QString query = parameters.trimmed();
+            const QString query = parameters.trimmed();
             QString helpMessage;
             foreach (QVariant mapVariant, m_commandDataList)
             {
@@ -209,6 +226,16 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
         commandReply = QDateTime::currentDateTime()
                                  .toLocalTime()
                                  .toString(Qt::SystemLocaleLongDate);
+
+        const qint64 uptime = m_globalObject->getConnectionStartTime()
+                                             .secsTo(QDateTime::currentDateTimeUtc());
+
+        commandReply.append("\nUp since: " /// TMP?
+                            + m_globalObject->getConnectionStartTime()
+                                             .toLocalTime()
+                                             .toString(Qt::SystemLocaleLongDate)
+                            + " ~ "
+                            + Helpers::durationString(uptime));
     }
     else //////////////////////////////////////////////// User-defined commands
     {
@@ -243,7 +270,7 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
                 {
                     QStringList replies = map.value("randomSentence")
                                              .toStringList();
-                    int stringNum = qrand() % replies.count();
+                    const int stringNum = qrand() % replies.count();
                     commandReply = replies.at(stringNum);
                 }
                 else if (commandType == 2)
@@ -381,14 +408,17 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
 
                     const QString aliasCommand = m_globalObject->getCommandPrefix()
                                                  + aliasFor
+                                                 + " "
                                                  + parameters;
                     qDebug() << "This is an alias for:" << aliasFor;
 
-                    // Protection againt infinite recursivity
+                    // Protection against infinite recursion
                     if (aliasFor.trimmed() != command)
                     {
                         // Recursive!
-                        commandReply = this->parseCommand(aliasCommand, userAccess)
+                        commandReply = this->parseCommand(aliasCommand,
+                                                          userAccess,
+                                                          callingUser)
                                              .value("replyString").toString();
                     }
                     else
@@ -403,18 +433,27 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess)
         }
     }
 
+    // Optional reply pattern; it can contain the actual reply, in %output%
     if (!outputPattern.isEmpty())
     {
-        outputPattern.replace("%output%", commandReply);
+        outputPattern.replace(QStringLiteral("%output%"), commandReply);
         commandReply = outputPattern;
     }
 
     // Parse and replace things like %line%, random choices in {a|b|c}, etc
     commandReply = m_variableParser->getParsed(commandReply);
 
+    // Original parameters can be used in reply via %params%
+    commandReply.replace(QStringLiteral("%params%"), parameters);
+
+    // A suitable name for the calling user will replace %user%
+    commandReply.replace(QStringLiteral("%user%"), callingUser);
+
+
     QVariantMap replyMap;
-    replyMap.insert("replyString", commandReply);
-    replyMap.insert("privateReply", privateReply);
+    replyMap.insert("replyString",      commandReply);
+    replyMap.insert("privateReply",     privateReply);
+    replyMap.insert("haveReplyPattern", !outputPattern.isEmpty());
 
     return replyMap;
 }
