@@ -159,9 +159,36 @@ CommandModule::CommandModule(CommandHandler *handler,
     this->aliasLineEdit = new QLineEdit(this);
 
 
+
     this->outputLineEdit = new QLineEdit(this);
-    this->outputLineEdit->setPlaceholderText(tr("Optional, like: [RESULT]")
-                                             + " %line%--- %output% ---");
+    this->outputLineEdit->setPlaceholderText(tr("Set an optional reply pattern"));
+
+    m_outputPatternHelpLabel = new QLabel(
+      tr("With a reply pattern you can make any possible reply to a command "
+         "fit into a predefined structure, like having a specific symbol at "
+         "the start or the end of the reply, or always start the reply with "
+         "a fixed word.")
+      + "<br />"
+      + tr("You can insert variables like %user%, %params%, %output%, %line% "
+           "and %smiley%.",
+           "Do not translate the words between % symbols")
+      + " "
+      + tr("Usually, you will want to have the %output% variable somewhere in "
+           "the pattern.",
+           "Do not translate %output%")
+      + "<br />"
+      + tr("If you don't set a reply pattern, replies in chatrooms will "
+           "use the default pattern, %user%: %output%.",
+           "Do not translate %user% or %output%")
+      + "<br /><br />"
+      + tr("Example: [RESULT] > %output%",
+           "Do not translate %output%"),
+      this);
+    m_outputPatternHelpLabel->setFont(helpFont);
+    m_outputPatternHelpLabel->setWordWrap(true);
+    m_outputPatternHelpLabel->setContentsMargins(16, 1, 16, 1);
+    m_outputPatternHelpLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
+                                            QSizePolicy::Minimum);
 
     this->privateReplyCheckbox = new QCheckBox(this);
 
@@ -198,10 +225,13 @@ CommandModule::CommandModule(CommandHandler *handler,
     formLayout->addRow(tr("Command"),         triggerLineEdit);
     formLayout->addRow(tr("Help Text"),       helpLineEdit);
     formLayout->addRow(tr("Access Level"),    accessLevelSpinbox);
+
     formLayout->addRow(tr("Type"),            typeCombobox);
     formLayout->addWidget(typeHelpLabel);
     formLayout->addRow(QString(), typeLayout);
+
     formLayout->addRow(tr("Reply Pattern"),   outputLineEdit);
+    formLayout->addWidget(m_outputPatternHelpLabel);
     formLayout->addRow(tr("Private Reply"),   privateReplyCheckbox);
 
 
