@@ -24,11 +24,11 @@
 #include <QWidget>
 #include <QVBoxLayout>
 #include <QFormLayout>
-#include <QHBoxLayout>
 #include <QLineEdit>
 #include <QCheckBox>
 #include <QSpinBox>
 #include <QPushButton>
+#include <QDialogButtonBox>
 #include <QAction>
 
 #include <QDebug>
@@ -60,21 +60,20 @@ public slots:
 
 
 private:
-    QVBoxLayout *mainLayout;
-    QFormLayout *topLayout;
-    QHBoxLayout *buttonLayout;
+    QVBoxLayout *m_mainLayout;
+    QFormLayout *m_topLayout;
+    QDialogButtonBox *m_bottomButtonBox;
 
-    QLineEdit *jidLineEdit;
-    QLineEdit *passwordLineEdit;
-    QCheckBox *autoconnectCheckbox;
+    QLineEdit *m_jidLineEdit;
+    QLineEdit *m_passwordLineEdit;
+    QCheckBox *m_autoconnectCheckbox;
 
-    QLineEdit *resourceLineEdit;
-    QSpinBox *prioritySpinbox;
+    QLineEdit *m_resourceLineEdit;
+    QSpinBox *m_prioritySpinbox;
 
-    QPushButton *connectButton;
-    QPushButton *cancelButton;
-
-    QAction *cancelAction;
+    QPushButton *m_connectButton;
+    QPushButton *m_cancelButton;
+    QAction *m_cancelAction;
 };
 
 #endif // CONNECTIONDIALOG_H
