@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -45,9 +45,9 @@ public slots:
 
 
 private:
-    QVBoxLayout *mainLayout;
+    QVBoxLayout *m_mainLayout;
 
-    QTreeWidget *conversationTreeWidget;
+    QTreeWidget *m_conversationTreeWidget;
 
 };
 
