@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,13 +23,13 @@
 
 DataFile::DataFile(QString filename, QObject *parent) : QObject(parent)
 {
-    this->dFile = new QFile(filename);
-    if (!dFile->exists())
+    m_file = new QFile(filename);
+    if (!m_file->exists())
     {
         // Initialize empty file
-        dFile->open(QIODevice::WriteOnly);
-        dFile->write(QByteArray());
-        dFile->close();
+        m_file->open(QIODevice::WriteOnly);
+        m_file->write(QByteArray());
+        m_file->close();
     }
 
 
@@ -39,38 +39,28 @@ DataFile::DataFile(QString filename, QObject *parent) : QObject(parent)
 
 DataFile::~DataFile()
 {
-    qDebug() << "DataFile destroyed for " << this->dFile->fileName();
+    qDebug() << "DataFile destroyed for " << m_file->fileName();
 }
 
 
 /*
  * Read command data from disk in JSON format.
  *
- * Uses QJSON when building with Qt 4.x,
- * and built-in Qt 5 methods otherwise.
- *
  */
 QVariantList DataFile::loadData()
 {
     QVariantList commandDataList;
     bool parsedOk = false;
 
-    dFile->open(QIODevice::ReadOnly);
+    m_file->open(QIODevice::ReadOnly);
 
-    QByteArray rawData = dFile->readAll();
-    dFile->close();
+    const QByteArray rawData = m_file->readAll();
+    m_file->close();
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    // Qt 4 version, requires QJSON
-    QJson::Parser jsonParser;
-    commandDataList = jsonParser.parse(rawData, &parsedOk).toList();
-#else
-    // Qt 5 version, using built-in classes
     QJsonDocument jsonDocument;
     jsonDocument = QJsonDocument::fromJson(rawData);
     commandDataList = jsonDocument.toVariant().toList();
     parsedOk = !jsonDocument.isNull();
-#endif
 
     if (!parsedOk)
     {
@@ -85,30 +75,19 @@ QVariantList DataFile::loadData()
 /*
  * Save command data to disk in JSON format.
  *
- * Uses QJSON when building with Qt 4.x, and
- * built-in Qt 5 methods when building with Qt 5.x.
- *
  */
 bool DataFile::saveData(QVariantList list)
 {
     QByteArray commandData;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    // Qt 4 version, using QJSON
-    QJson::Serializer serializer;
-    serializer.setIndentMode(QJson::IndentFull); // More readable output
-    commandData = serializer.serialize(list);
-#else
-    // Qt 5 version, with built-in methods
     QJsonDocument jsonDocument;
     jsonDocument = QJsonDocument::fromVariant(list);
     commandData = jsonDocument.toJson(QJsonDocument::Indented);
-#endif
 
 
-    dFile->open(QIODevice::WriteOnly);
-    int written = dFile->write(commandData);
-    dFile->close();
+    m_file->open(QIODevice::WriteOnly);
+    const int written = m_file->write(commandData);
+    m_file->close();
 
     if (written < 1) // 0 bytes, or -1 for Error
     {
