@@ -32,7 +32,7 @@ class Helpers : public QObject
     Q_OBJECT
 
 public:
-    explicit Helpers(QObject *parent = 0);
+    explicit Helpers(QObject *parent = nullptr);
     ~Helpers();
 
     static bool isValidJid(QString jid);
@@ -44,7 +44,7 @@ public:
     static int randomBetween(int lowNum, int highNum);
     static bool probability(int chancePercent);
 
-
+    static QString durationString(qint64 seconds);
 
 signals:
 
