@@ -24,7 +24,8 @@
 LogModule::LogModule(QWidget *parent) : QTextBrowser(parent)
 {
     this->setReadOnly(true);
-    this->addToLog(tr("AkariXB started."));
+    this->addToLog(tr("AkariXB v%1 started.",
+                      "%1 = Version number").arg(qApp->applicationVersion()));
 
     qDebug() << "LogModule created";
 }
