@@ -23,6 +23,7 @@
 
 #include <QTextBrowser>
 #include <QTime>
+#include <QApplication>
 
 #include <QDebug>
 
@@ -32,7 +33,7 @@ class LogModule : public QTextBrowser
     Q_OBJECT
 
 public:
-    explicit LogModule(QWidget *parent = 0);
+    explicit LogModule(QWidget *parent = nullptr);
     ~LogModule();
 
 signals:
