@@ -30,9 +30,9 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     // Ensure closing a dialog while the main window is hidden, won't end the program
     qApp->setQuitOnLastWindowClosed(false);
 
-    this->globalObject = new GlobalObject(this);
-    connect(globalObject, SIGNAL(showInStatusBar(QString)),
-            this, SLOT(setStatusBarMessage(QString)));
+    m_globalObject = new GlobalObject(this);
+    connect(m_globalObject, &GlobalObject::showInStatusBar,
+            this, &MainWindow::setStatusBarMessage);
 
 
 #if 0 // Set to 1 to test the fallback icons
@@ -43,11 +43,11 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     // It's important to initialize this before creating the handlers, which use it
     this->variableParser = new VariableParser(this);
-    this->globalObject->setVariableParser(variableParser);
+    m_globalObject->setVariableParser(variableParser);
 
-    this->messageHandler = new MessageHandler(globalObject, this);
-    this->commandHandler = new CommandHandler(globalObject, this);
-    this->activityHandler = new ActivityHandler(globalObject, this);
+    this->messageHandler = new MessageHandler(m_globalObject, this);
+    this->commandHandler = new CommandHandler(m_globalObject, this);
+    this->activityHandler = new ActivityHandler(m_globalObject, this);
 
 
     // Page 8, runtime log, needed before others for early logging
@@ -57,31 +57,30 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
                              qApp->platformName(),
                              QXmppVersion(),
                              QSysInfo::prettyProductName()));
-    connect(globalObject, SIGNAL(logMessage(QString)),
-            logModule, SLOT(addToLog(QString)));
+    connect(m_globalObject, &GlobalObject::logMessage,
+            logModule, &LogModule::addToLog);
 
     createDataDir();
 
 
-    this->configDialog = new ConfigDialog(this->globalObject, this);
+    this->configDialog = new ConfigDialog(m_globalObject, this);
 
 
 
     // Page 1, general
-    this->generalModule = new GeneralModule(this->globalObject, this);
+    this->generalModule = new GeneralModule(m_globalObject, this);
 
     // Page 2, MUCs
-    this->roomModule = new RoomModule(this->globalObject, this);
+    this->roomModule = new RoomModule(m_globalObject, this);
 
     // Page 3, private chats
-    this->chatModule = new ChatModule(this->globalObject, this);
+    this->chatModule = new ChatModule(m_globalObject, this);
     connect(chatModule, SIGNAL(unreadCountChanged(int)),
             this, SLOT(setChatsTitle(int)));
 
-
     // Page 4, commands
     this->commandModule = new CommandModule(this->commandHandler,
-                                            this->globalObject,
+                                            m_globalObject,
                                             this);
 
     // Page 5, conversations
@@ -89,11 +88,11 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     // Page 6, activities
     this->activityModule = new ActivityModule(this->activityHandler,
-                                              this->globalObject,
+                                              m_globalObject,
                                               this);
 
     // Page 7, identity
-    this->identityModule = new IdentityModule(this->globalObject, this);
+    this->identityModule = new IdentityModule(m_globalObject, this);
 
 
 
@@ -161,16 +160,18 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     loadSettings();
 
 
-    this->connectionDialog = new ConnectionDialog(this->userJid,
-                                                  this->userPassword,
-                                                  this->userAutoconnect,
-                                                  this->userResource,
-                                                  this->userPriority,
+    this->connectionDialog = new ConnectionDialog(m_userJid,
+                                                  m_userPassword,
+                                                  m_userAutoconnect,
+                                                  m_userResource,
+                                                  m_userPriority,
                                                   this);
     connect(connectionDialog, SIGNAL(connectionRequested(QString,QString,bool,QString,int)),
             this, SLOT(connectToServer(QString,QString,bool,QString,int)));
     connect(generalModule, SIGNAL(connectionRequested()),
             connectionDialog, SLOT(show()));
+    connect(generalModule, &GeneralModule::disconnectionRequested,
+            this, &MainWindow::disconnectFromServer);
 
 
     createMenus();
@@ -181,23 +182,32 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     this->categoriesList->setCurrentRow(0);
     this->setTitleAndTrayInfo();
 
+    /*
+     * If initial connection hangs for some reason, break it and retry after
+     * a relatively short time, to avoid connection limbo.
+     *
+     * See https://github.com/qxmpp-project/qxmpp/issues/166
+     */
+    m_initialConnectionTimer = new QTimer(this);
+    m_initialConnectionTimer->setSingleShot(true);
+    m_initialConnectionTimer->setInterval(60000); // 60 sec, hardcoded, FIXME
+    connect(m_initialConnectionTimer, &QTimer::timeout,
+            this, &MainWindow::onConnectionTimerAbort);
+
+
     this->statusBar()->showMessage(tr("Ready."));
 
 
-    if (this->userJid.isEmpty())
+    if (m_userJid.isEmpty())
     {
-        if (!this->globalObject->getHideInTray())
+        if (!m_globalObject->getHideInTray())
         {
             connectionDialog->show();
         }
     }
-    else if (this->userAutoconnect)
+    else if (m_userAutoconnect)
     {
-        this->connectToServer(this->userJid,
-                              this->userPassword,
-                              this->userAutoconnect,
-                              this->userResource,
-                              this->userPriority);
+        this->autoConnectToServer();
     }
 
     qDebug() << "MainWindow created";
@@ -229,8 +239,8 @@ void MainWindow::createMenus()
                                                 this);
     sessionDisconnectAction->setDisabled(true);
     sessionDisconnectAction->setShortcut(QKeySequence("Ctrl+Shift+D"));
-    connect(sessionDisconnectAction, SIGNAL(triggered()),
-            xmppClient, SLOT(disconnectFromServer()));
+    connect(sessionDisconnectAction, &QAction::triggered,
+            this, &MainWindow::disconnectFromServer);
 
 
     this->sessionQuitAction = new QAction(QIcon::fromTheme("application-exit"),
@@ -306,8 +316,8 @@ void MainWindow::createMenus()
     trayShowWindowAction = new QAction(QIcon(":/icon/64x64/akarixb.png"),
                                        "*show-hide-window*",
                                        this);
-    connect(trayShowWindowAction, SIGNAL(triggered()),
-            this, SLOT(toggleMainWindow()));
+    connect(trayShowWindowAction, &QAction::triggered,
+            this, &MainWindow::toggleMainWindow);
 
 
     this->systrayMenu = new QMenu("*systray-menu*", this);
@@ -340,8 +350,8 @@ void MainWindow::createTrayIcon()
                 this, SLOT(show()));  // FIXME: this can mess up the first action in the context menu
 
         // Show notifications requested via GlobalObject
-        connect(globalObject, SIGNAL(showNotificationPopup(QString,QString)),
-                this, SLOT(showNotification(QString,QString)));
+        connect(m_globalObject, &GlobalObject::showNotificationPopup,
+                this, &MainWindow::showNotification);
 
         // Set contextual menu for the icon
         systrayIcon->setContextMenu(systrayMenu);
@@ -363,8 +373,8 @@ void MainWindow::createStatusBarWidgets()
 {
     this->statusBarLabel = new QLabel(this);
     this->setStatusIconOnline(QXmppPresence::Online, false);
-    connect(globalObject, SIGNAL(statusChanged(QXmppPresence)),
-            this, SLOT(onStatusChanged(QXmppPresence)));
+    connect(m_globalObject, &GlobalObject::statusChanged,
+            this, &MainWindow::onStatusChanged);
 
     this->statusBar()->addPermanentWidget(statusBarLabel);
     this->statusBar()->setSizeGripEnabled(false);
@@ -378,7 +388,7 @@ void MainWindow::createDataDir()
     dataDirectory = QStandardPaths::standardLocations(QStandardPaths::DataLocation)
                                    .first();
 
-    this->globalObject->setDataDirectory(dataDirectory);
+    m_globalObject->setDataDirectory(dataDirectory);
     qDebug() << "Data directory:" << dataDirectory;
 
     QDir dataDir;
@@ -387,21 +397,21 @@ void MainWindow::createDataDir()
         qDebug() << "Creating data directory";
         if (dataDir.mkpath(dataDirectory))
         {
-            this->globalObject->addToLog(tr("Data directory created: %1")
-                                         .arg(dataDirectory));
+            m_globalObject->addToLog(tr("Data directory created: %1")
+                                     .arg(dataDirectory));
             qDebug() << "Data directory created:" << dataDirectory;
         }
         else
         {
-            this->globalObject->addToLog(tr("Error creating data directory: %1")
-                                         .arg(dataDirectory));
+            m_globalObject->addToLog(tr("Error creating data directory: %1")
+                                     .arg(dataDirectory));
             qDebug() << "Error creating data directory!";
         }
     }
     else
     {
-        this->globalObject->addToLog(tr("Data directory in use: %1")
-                                     .arg(dataDirectory));
+        m_globalObject->addToLog(tr("Data directory in use: %1")
+                                 .arg(dataDirectory));
     }
 
     if (!dataDir.exists(dataDirectory + "/logs"))
@@ -422,40 +432,41 @@ void MainWindow::createDataDir()
 
 void MainWindow::setupXmppClient()
 {
-    this->xmppClient = new QXmppClient(this);
-    xmppClient->versionManager().setClientName("AkariXB");
-    xmppClient->versionManager().setClientOs("Akari-GNU-OS"); // tmp FIXME xD
+    m_xmppClient = new QXmppClient(this);
+    m_xmppClient->versionManager().setClientName("AkariXB");
+    m_xmppClient->versionManager().setClientOs("Akari-GNU-OS"); // tmp FIXME xD
+    m_disconnectedManually = false;
 
-#if 0  // Verbose XMPP console
-    xmppClient->logger()->setLoggingType(QXmppLogger::StdoutLogging);
-#endif
+    connect(m_xmppClient, &QXmppClient::connected,
+            this, &MainWindow::onConnected);
+    connect(m_xmppClient, &QXmppClient::disconnected,
+            this, &MainWindow::onDisconnected);
 
-    connect(xmppClient, SIGNAL(connected()),
-            this, SLOT(onConnected()));
-    connect(xmppClient, SIGNAL(disconnected()),
-            this, SLOT(onDisconnected()));
+    connect(m_xmppClient, &QXmppClient::messageReceived,
+            this, &MainWindow::processMessage);
+    connect(m_xmppClient, &QXmppClient::presenceReceived,
+            this, &MainWindow::processPresence);
+    connect(m_xmppClient, &QXmppClient::iqReceived,
+            this, &MainWindow::processIq);
 
-    connect(xmppClient, SIGNAL(messageReceived(QXmppMessage)),
-            this, SLOT(processMessage(QXmppMessage)));
+    connect(m_xmppClient, &QXmppClient::error,
+            this, &MainWindow::onNetworkError);
 
-    connect(xmppClient, SIGNAL(presenceReceived(QXmppPresence)),
-            this, SLOT(processPresence(QXmppPresence)));
+    m_mucManager = new QXmppMucManager();
+    m_xmppClient->addExtension(m_mucManager);
 
-    connect(xmppClient, SIGNAL(iqReceived(QXmppIq)),
-            this, SLOT(processIq(QXmppIq)));
-
-    connect(xmppClient, SIGNAL(error(QXmppClient::Error)),
-            this, SLOT(onNetworkError(QXmppClient::Error)));
-
-    this->mucManager = new QXmppMucManager();
-    xmppClient->addExtension(mucManager);
-
-    this->receiptManager = new QXmppMessageReceiptManager();
-    xmppClient->addExtension(receiptManager);
+    m_receiptManager = new QXmppMessageReceiptManager();
+    m_xmppClient->addExtension(m_receiptManager);
 
 
-    this->globalObject->setXmppClient(this->xmppClient);
-    this->globalObject->setMucManager(this->mucManager);
+    m_globalObject->setXmppClient(m_xmppClient);
+    m_globalObject->setMucManager(m_mucManager);
+}
+
+
+void MainWindow::enableXmppDebug()
+{
+    m_xmppClient->logger()->setLoggingType(QXmppLogger::StdoutLogging);
 }
 
 
@@ -465,12 +476,13 @@ void MainWindow::loadSettings()
 {
     QSettings settings;
     settings.beginGroup("Connection");
-    this->userJid = settings.value("jid").toString();
-    this->userPassword = QByteArray::fromBase64(settings.value("password")
-                                                        .toByteArray());
-    this->userAutoconnect = settings.value("autoconnect").toBool();
-    this->userResource = settings.value("resource", "AkariXB").toString();
-    this->userPriority = settings.value("priority", 10).toInt();
+    m_userJid = settings.value("jid").toString();
+    m_userPassword = QByteArray::fromBase64(settings.value("password")
+                                                    .toByteArray());
+    m_userAutoconnect = settings.value("autoconnect").toBool();
+    m_userResource = settings.value("resource", QStringLiteral("AkariXB"))
+                             .toString();
+    m_userPriority = settings.value("priority", 10).toInt();
     settings.endGroup();
 
 
@@ -490,12 +502,11 @@ void MainWindow::saveSettings()
 {
     QSettings settings;
     settings.beginGroup("Connection");
-    settings.setValue("jid",         this->userJid);
-    settings.setValue("password",
-                      this->userPassword.toLocal8Bit().toBase64());
-    settings.setValue("autoconnect", this->userAutoconnect);
-    settings.setValue("resource",    this->userResource);
-    settings.setValue("priority",    this->userPriority);
+    settings.setValue("jid",         m_userJid);
+    settings.setValue("password",    m_userPassword.toLocal8Bit().toBase64());
+    settings.setValue("autoconnect", m_userAutoconnect);
+    settings.setValue("resource",    m_userResource);
+    settings.setValue("priority",    m_userPriority);
     settings.endGroup();
 
 
@@ -557,36 +568,52 @@ void MainWindow::connectToServer(QString jid, QString password,
                                  bool autoconnect, QString resource,
                                  int priority)
 {
-    this->userJid = jid;
-    this->userPassword = password;
-    this->userAutoconnect = autoconnect;
-    this->userResource = resource;
-    this->userPriority = priority;
+    m_userJid = jid;
+    m_userPassword = password;
+    m_userAutoconnect = autoconnect;
+    m_userResource = resource;
+    m_userPriority = priority;
 
-    QString message = tr("Connecting...");
+    const QString message = tr("Connecting...");
     this->generalModule->setInfoMessage(message);
-    this->globalObject->addToLog(message);
+    m_globalObject->addToLog(message);
 
     this->generalModule->setConnecting();
     this->sessionConnectAction->setDisabled(true);
 
     QXmppConfiguration clientConfig;
-    clientConfig.setJid(userJid);
-    clientConfig.setResource(userResource);
-    clientConfig.setPassword(password);
-    clientConfig.setKeepAliveTimeout(this->globalObject->getKeepAliveTimeout());
-    clientConfig.setKeepAliveInterval(this->globalObject->getKeepAliveInterval());
+    clientConfig.setJid(m_userJid);
+    clientConfig.setResource(m_userResource);
+    clientConfig.setPassword(m_userPassword);
+    clientConfig.setKeepAliveInterval(m_globalObject->getKeepAliveInterval());
+    clientConfig.setKeepAliveTimeout(m_globalObject->getKeepAliveTimeout());
+    clientConfig.setAutoReconnectionEnabled(false);
 
-    this->xmppClient->connectToServer(clientConfig);
+    m_disconnectedManually = false;
+    m_initialConnectionTimer->start();
+
+    m_xmppClient->connectToServer(clientConfig);
+}
+
+
+void MainWindow::autoConnectToServer()
+{
+    this->connectToServer(m_userJid,
+                          m_userPassword,
+                          m_userAutoconnect,
+                          m_userResource,
+                          m_userPriority);
 }
 
 
 
 void MainWindow::onConnected()
 {
-    QString message = tr("%1 connected.").arg(this->userJid);
+    const QString message = tr("%1 connected.").arg(m_userJid);
     this->generalModule->setInfoMessage(message);
-    this->globalObject->addToLog(message);
+    m_globalObject->addToLog(message);
+
+    m_initialConnectionTimer->stop();
 
     QStringList statusMessages;    // TMP hardcoded 'default' messages
     statusMessages << "H{i|ii|iii}!"
@@ -595,50 +622,87 @@ void MainWindow::onConnected()
                    << "I'm around...";
 
     QXmppPresence presence;
-    presence.setPriority(this->userPriority);
+    presence.setPriority(m_userPriority);
     presence.setAvailableStatusType(QXmppPresence::Online);
-    presence.setStatusText(this->variableParser->getParsed(Helpers::randomString(statusMessages)));
-    this->xmppClient->setClientPresence(presence);
+    presence.setStatusText(this->variableParser
+                               ->getParsed(Helpers::randomString(statusMessages)));
+    m_xmppClient->setClientPresence(presence);
+
+    // Need to disable this here again, for auto-reconnections
+    this->sessionConnectAction->setDisabled(true);
 
-    this->sessionConnectAction->setDisabled(true); // Need to disable this here again, for auto-reconnections
     this->sessionDisconnectAction->setEnabled(true);
 
     this->roomModule->autojoinRooms();
 
-    this->globalObject->setConnected(true);
+    m_globalObject->setConnected(true);
     this->setTitleAndTrayInfo();
     this->setStatusIconOnline(QXmppPresence::Online, true);
 }
 
 
+void MainWindow::disconnectFromServer()
+{
+    m_initialConnectionTimer->stop();
+    m_disconnectedManually = true;
+    m_xmppClient->disconnectFromServer();
+}
+
+
 void MainWindow::onDisconnected()
 {
     const QString message = tr("Disconnected.");
     this->generalModule->setInfoMessage(message);
-    this->globalObject->addToLog(message);
+    m_globalObject->addToLog(message);
+    qDebug() << "\n"
+                "\n=========================================================="
+                "\n======================-DISCONNECTED-======================"
+                "\n=========================================================="
+                "\n";
 
     this->sessionDisconnectAction->setDisabled(true);
     this->sessionConnectAction->setEnabled(true);
 
-    this->globalObject->setConnected(false);
+    m_globalObject->setConnected(false);
     this->setTitleAndTrayInfo();
     this->setStatusIconOnline(QXmppPresence::Online, false);
 
-    if (globalObject->getNotifyDisconnection())
+    if (!m_disconnectedManually)
     {
-        // FIXME: don't show notification if disconnection is manual
-        globalObject->showNotification(tr("Disconnected"),
-                                       tr("Connection to the server was lost."));
-    }
+        // We only notify the disconnection if it wasn't manual
+        if (m_globalObject->getNotifyDisconnection())
+        {
+            m_globalObject->showNotification(tr("Disconnected"),
+                                             tr("Connection to the server "
+                                                "was lost."));
+        }
 
-    // TODO: optional email notification for this event
+        // TODO: optional email notification for this event
+
+        this->autoConnectToServer(); // FIXME: autoreconnection should be optional
+    }
+}
+
+/*
+ * Workaround for https://github.com/qxmpp-project/qxmpp/issues/166
+ *
+ */
+void MainWindow::onConnectionTimerAbort()
+{
+    m_globalObject->addToLog(tr("Connection seems stuck. Trying again..."));
+    qDebug() << "==========================================================\n"
+                "==============-ABORTING CONNECTION BY TIMER-==============\n"
+                "==========================================================\n";
+    m_initialConnectionTimer->stop();
+    m_disconnectedManually = false;
+    this->autoConnectToServer();
 }
 
 
 void MainWindow::onStatusChanged(QXmppPresence presence)
 {
     this->setStatusIconOnline(presence.availableStatusType(),
-                              this->globalObject->connectedToServer());
+                              m_globalObject->connectedToServer());
 }
 
 
@@ -646,7 +710,8 @@ void MainWindow::processMessage(QXmppMessage message)
 {
     // Send private messages to their tabs, first (order is important)
     if (message.type() == QXmppMessage::Chat
-     || message.type() == QXmppMessage::Normal)
+     || message.type() == QXmppMessage::Normal
+     || message.type() == QXmppMessage::Headline) // TMP: This one could use its own place
     {
         // Ignore completely empty messages (from ChatState changes, etc)
         // FIXME: In the future, show these state changes somewhere else
@@ -658,7 +723,7 @@ void MainWindow::processMessage(QXmppMessage message)
 
 
     // Afterwards, actually process the received message
-    if (message.body().startsWith(this->globalObject->getCommandPrefix())
+    if (message.body().startsWith(m_globalObject->getCommandPrefix())
      && message.type() != QXmppMessage::Error)
     {
         this->commandHandler->processCommand(message);
@@ -698,7 +763,8 @@ void MainWindow::onNetworkError(QXmppClient::Error error)
     switch (error)
     {
     case QXmppClient::SocketError:
-        errorString = tr("Socket Error");
+        errorString = tr("Socket Error")
+                      + " (" + m_xmppClient->socketErrorString() + ")";
         break;
 
     case QXmppClient::KeepAliveError:
@@ -707,15 +773,17 @@ void MainWindow::onNetworkError(QXmppClient::Error error)
 
     case QXmppClient::XmppStreamError:
         errorString = tr("XMPP Stream Error");
+        // If error is related to server shutdown, we might need to force reconnection
+        qDebug() << "::: XMPP Stream Error:" << m_xmppClient->xmppStreamError();
         break;
 
     default:
-        errorString = "NoError";
+        errorString = QStringLiteral("NoError");
     }
 
 
-    QString message = tr("Network error: %1").arg(errorString);
-    this->globalObject->addToLog(message);
+    const QString message = tr("Network error: %1").arg(errorString);
+    m_globalObject->addToLog(message);
 
     //qDebug() << "Network error:"
     //         << "\nStanza:" << this->xmppClient->xmppStreamError()
@@ -830,13 +898,12 @@ void MainWindow::setTitleAndTrayInfo()
     }
 
     QString title = currentTabTitle;
-    if (!this->userJid.isEmpty())
+    if (!m_userJid.isEmpty())
     {
-        title.append(QString(" - %1/%2")
-                     .arg(this->userJid, this->userResource));
+        title.append(QString(" - %1/%2").arg(m_userJid, m_userResource));
     }
 
-    if (this->globalObject->connectedToServer())
+    if (m_globalObject->connectedToServer())
     {
         this->systrayIcon->setIcon(QIcon(":/icon/64x64/akarixb.png"));
     }
@@ -851,29 +918,29 @@ void MainWindow::setTitleAndTrayInfo()
     this->setWindowTitle(title);
     if (/*trayIconAvailable*/true) // FIXME
     {
-        const QString idToShow = this->userJid.isEmpty()
+        const QString idToShow = m_userJid.isEmpty()
                                  ? tr("Account is not configured")
-                                 : userJid + "/" + userResource;
+                                 : m_userJid + "/" + m_userResource;
 #ifdef Q_OS_UNIX
         title = "<b>AkariXB</b>"
                 "<hr>"
                 "<br>"
                 + idToShow
-                + (this->globalObject->connectedToServer() ?
-                   "" : offlineString);
+                + (m_globalObject->connectedToServer() ?
+                   QString() : offlineString);
 #else
         // Some OSes don't render HTML in the tray tooltip
         title = "AkariXB: "
                 "\n\n"
                 + idToShow
-                + (this->globalObject->connectedToServer() ?
-                   "" : offlineString);
+                + (m_globalObject->connectedToServer() ?
+                   QString() : offlineString);
 #endif
 
 
         this->systrayIcon->setToolTip(title);
 
-        this->trayTitleSeparatorAction->setText("AkariXB - " + this->userJid);
+        this->trayTitleSeparatorAction->setText("AkariXB - " + m_userJid);
     }
 }
 
@@ -935,7 +1002,7 @@ void MainWindow::toggleMainWindow(bool onStartup)
     bool shouldHide = false;
     if (onStartup)
     {
-        shouldHide = this->globalObject->getHideInTray();
+        shouldHide = m_globalObject->getHideInTray();
     }
 
     if (this->isHidden() && !shouldHide
@@ -960,14 +1027,15 @@ void MainWindow::quitProgram()
 {
     if (this->isHidden())
     {
-        this->show();
+        this->toggleMainWindow();
     }
 
     // FIXME: make confirmation optional, with option of asking only if via tray
-    int confirmation = QMessageBox::question(this, tr("Quit?") + " - AkariXB",
+    int confirmation = QMessageBox::question(this,
+                                             tr("Quit?") + " - AkariXB",
                                              tr("Are you sure?"),
                                              tr("Yes, quit AkariXB"), tr("No"),
-                                             "", 1, 1);
+                                             QString(), 1, 1);
     if (confirmation == 1)
     {
         return;
@@ -976,11 +1044,11 @@ void MainWindow::quitProgram()
 
     qApp->setQuitOnLastWindowClosed(true);
 
-    std::cout << "\nShutting down AkariXB (" + this->userJid.toStdString()
+    std::cout << "\nShutting down AkariXB (" + m_userJid.toStdString()
                  + ")...\n";
     std::cout.flush();
 
-    this->xmppClient->disconnectFromServer();
+    m_xmppClient->disconnectFromServer();
     qApp->closeAllWindows();
 
     std::cout << "All windows closed, bye! o/\n";
@@ -1004,6 +1072,7 @@ void MainWindow::resizeEvent(QResizeEvent *event)
 void MainWindow::closeEvent(QCloseEvent *event)
 {
     qDebug() << "Trying to close window; hiding instead";
-    this->hide(); // FIXME: only if tray icon was available; also, manage environment shutdown
+    this->toggleMainWindow(); // FIXME: only if tray icon was available
+                              // Also, handle environment shutdown
     event->ignore();
 }
