@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -53,11 +53,11 @@ public slots:
 
 
 private:
-    QXmppClient *xmppClient;
-    QXmppMucManager *mucManager;
+    QXmppClient *m_xmppClient;
+    QXmppMucManager *m_mucManager;
 
-    GlobalObject *globalObj;
-    VariableParser *varParser;
+    GlobalObject *m_globalObject;
+    VariableParser *m_variableParser;
 };
 
 #endif // MESSAGEHANDLER_H
