@@ -71,19 +71,19 @@
     </message>
     <message>
         <source>Several rooms</source>
-        <translation type="unfinished">Algunes sales</translation>
+        <translation>Algunes sales</translation>
     </message>
     <message>
         <source>A few rooms</source>
-        <translation type="unfinished">Unes poques sales</translation>
+        <translation>Unes poques sales</translation>
     </message>
     <message>
         <source>Also to active private chats</source>
-        <translation type="unfinished">També a converses privades actives</translation>
+        <translation>També a converses privades actives</translation>
     </message>
     <message>
         <source>Sa&amp;ve Activity</source>
-        <translation type="unfinished">&amp;Guardar activitat</translation>
+        <translation>&amp;Guardar activitat</translation>
     </message>
     <message>
         <source>Name</source>
@@ -91,7 +91,7 @@
     </message>
     <message>
         <source>Maximum Times Per Day</source>
-        <translation type="unfinished"></translation>
+        <translation>Màxim de vegades per dia</translation>
     </message>
     <message>
         <source>Probability</source>
@@ -99,11 +99,11 @@
     </message>
     <message>
         <source>Time Range</source>
-        <translation type="unfinished">Rang d&apos;hores</translation>
+        <translation>Rang d&apos;hores</translation>
     </message>
     <message>
         <source>Date Range</source>
-        <translation type="unfinished">Rang de dates</translation>
+        <translation>Rang de dates</translation>
     </message>
     <message>
         <source>Duration</source>
@@ -111,7 +111,7 @@
     </message>
     <message>
         <source>Set Status Type</source>
-        <translation type="unfinished">Establir el tipus d&apos;estat</translation>
+        <translation>Establir el tipus d&apos;estat</translation>
     </message>
     <message>
         <source>Availability</source>
@@ -135,7 +135,7 @@
     </message>
     <message>
         <source>&amp;Sync Activities</source>
-        <translation type="unfinished">&amp;Sincronitzar activitats</translation>
+        <translation>&amp;Sincronitzar activitats</translation>
     </message>
     <message>
         <source>&amp;Remove Activity</source>
@@ -202,7 +202,7 @@
     </message>
     <message>
         <source>A new chat was started by %1.</source>
-        <translation type="unfinished">%1 ha començat una nova conversa.</translation>
+        <translation>%1 ha començat una nova conversa.</translation>
     </message>
 </context>
 <context>
@@ -213,38 +213,39 @@
     </message>
     <message>
         <source>Kicked from the room!</source>
-        <translation type="unfinished"></translation>
+        <translation>Expulsat de la sala!</translation>
     </message>
     <message>
         <source>Joined room %1, as %2.</source>
+        <translatorcomment>No m&apos;agrada</translatorcomment>
         <translation type="unfinished">S&apos;ha entrat a la sala %1, com %2.</translation>
     </message>
     <message>
         <source>Left room %1.</source>
-        <translation type="unfinished">S&apos;ha sortit de la sala %1.</translation>
+        <translation>S&apos;ha sortit de la sala %1.</translation>
     </message>
 </context>
 <context>
     <name>CommandHandler</name>
     <message>
         <source>Command from %1 in room %2: %3</source>
-        <translation type="unfinished"></translation>
+        <translation>Ordre de %1 a la sala %2: %3</translation>
     </message>
     <message>
         <source>Command from %1: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Ordre de %1: %2</translation>
     </message>
     <message>
         <source>The command failed.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Ha fallat l&apos;ordre.</translation>
     </message>
     <message>
         <source>Error loading file %1 for command: %2</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Error al carregar l&apos;arxiu %1 per a la ordre: %2</translation>
     </message>
     <message>
         <source>Command gave no output text.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">La ordre no ha donat cap text de sortida.</translation>
     </message>
     <message>
         <source>I don&apos;t have help about: %1</source>
@@ -256,35 +257,31 @@
     </message>
     <message>
         <source>Available commands</source>
-        <translation type="unfinished"></translation>
+        <translation>Ordres disponibles</translation>
     </message>
     <message>
         <source>Command %1 requested without the right access level.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>I need a parameter for the query.</source>
-        <translation type="vanished">Necessito un paràmetre per la consulta.</translation>
+        <translation type="unfinished">S&apos;ha demanat la ordre %1 sense el nivell d&apos;accés adequat.</translation>
     </message>
     <message>
         <source>I don&apos;t have a match for %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">No tinc cap coincidència per a %1</translation>
     </message>
     <message>
         <source>This command is an alias to itself!</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Aquesta ordre és un àlies per ella mateixa!</translation>
     </message>
     <message>
         <source>Use %1 to list the available commands.</source>
-        <translation type="unfinished"></translation>
+        <translation>Utilitza %1 per a llistar les ordres disponibles.</translation>
     </message>
     <message>
         <source>Use %1 [command] to get help about a specific command.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Utilitza %1 [ordre] per rebre ajuda sobre una ordre específica.</translation>
     </message>
     <message>
         <source>Started detached program successfully.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">S&apos;ha iniciat el programa independent correctament.</translation>
     </message>
     <message>
         <source>I need a parameter for the query:</source>
@@ -295,7 +292,7 @@
     <name>CommandModule</name>
     <message>
         <source>&amp;Add Command</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Afegir ordre</translation>
     </message>
     <message>
         <source>Static Message</source>
@@ -303,15 +300,15 @@
     </message>
     <message>
         <source>Random Sentence</source>
-        <translation type="unfinished">Frase aleatòria</translation>
+        <translation>Frase aleatòria</translation>
     </message>
     <message>
         <source>Save &amp;Command</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Guardar &amp;ordre</translation>
     </message>
     <message>
         <source>Command</source>
-        <translation type="unfinished"></translation>
+        <translation>Ordre</translation>
     </message>
     <message>
         <source>Help Text</source>
@@ -327,11 +324,11 @@
     </message>
     <message>
         <source>&amp;Sync Commands</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Sincronitzar ordres</translation>
     </message>
     <message>
         <source>&amp;Remove Command</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Treure ordre</translation>
     </message>
     <message>
         <source>Anyone can use it</source>
@@ -368,7 +365,7 @@
     </message>
     <message>
         <source>There is no program specified.</source>
-        <translation type="unfinished">No s&apos;ha especificat cap programa.</translation>
+        <translation>No s&apos;ha especificat cap programa.</translation>
     </message>
     <message>
         <source>You need to enter the command this alias will execute.</source>
@@ -376,7 +373,7 @@
     </message>
     <message>
         <source>Error validating fields</source>
-        <translation type="unfinished"></translation>
+        <translation>Error al validar els camps</translation>
     </message>
     <message>
         <source>Select a text file</source>
@@ -388,7 +385,7 @@
     </message>
     <message>
         <source>New Command</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Nova ordre</translation>
     </message>
     <message>
         <source>No file selected</source>
@@ -396,11 +393,11 @@
     </message>
     <message>
         <source>Command exists</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">L&apos;ordre ja existeix</translation>
     </message>
     <message>
         <source>Just enter a single sentence.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Introdueix una sola frase.</translation>
     </message>
     <message>
         <source>Add as many sentences as you want.
@@ -426,7 +423,7 @@ File encoding should be UTF-8.</source>
     </message>
     <message>
         <source>Private Reply</source>
-        <translation type="unfinished">Resposta privada</translation>
+        <translation type="unfinished">Resposta en privat</translation>
     </message>
     <message>
         <source>There are no keywords in the list.</source>
@@ -462,17 +459,13 @@ File encoding should be UTF-8.</source>
         <source>Launch the program independently</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Optional, like: [RESULT]</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>The name, without the prefix</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">El nom, sense el prefix</translation>
     </message>
     <message>
         <source>Error: There is already a command in the list with this name.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Error: Ja hi ha una ordre a la llista amb aquest nom.</translation>
     </message>
     <message>
         <source>Enter a system command line to be run, with any needed parameters.
@@ -482,6 +475,34 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Reply Pattern</source>
+        <translation type="unfinished">Patró de resposta</translation>
+    </message>
+    <message>
+        <source>Set an optional reply pattern</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>With a reply pattern you can make any possible reply to a command fit into a predefined structure, like having a specific symbol at the start or the end of the reply, or always start the reply with a fixed word.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You can insert variables like %user%, %params%, %output%, %line% and %smiley%.</source>
+        <comment>Do not translate the words between % symbols</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Usually, you will want to have the %output% variable somewhere in the pattern.</source>
+        <comment>Do not translate %output%</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If you don&apos;t set a reply pattern, replies in chatrooms will use the default pattern, %user%: %output%.</source>
+        <comment>Do not translate %user% or %output%</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Example: [RESULT] &gt; %output%</source>
+        <comment>Do not translate %output%</comment>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -493,7 +514,7 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>&amp;Save</source>
-        <translation type="unfinished">&amp;Guardar</translation>
+        <translation>&amp;Guardar</translation>
     </message>
     <message>
         <source>General</source>
@@ -505,15 +526,15 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Command prefix</source>
-        <translation type="unfinished">Prefix d&apos;ordres</translation>
+        <translation>Prefix d&apos;ordres</translation>
     </message>
     <message>
         <source>Notify new chats</source>
-        <translation type="unfinished">Notificar de noves converses</translation>
+        <translation>Notificar de noves converses</translation>
     </message>
     <message>
         <source>Hide window on startup</source>
-        <translation type="unfinished"></translation>
+        <translation>Amagar la finestra a l&apos;inici</translation>
     </message>
     <message>
         <source>Notifications</source>
@@ -521,7 +542,7 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>System Tray</source>
-        <translation type="unfinished"></translation>
+        <translation>Safata del sistema</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -549,7 +570,7 @@ The reply will be the console output of the program, unless you specify a reply
     <name>ConnectionDialog</name>
     <message>
         <source>Connection Settings</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Configuració de la connexió</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -577,7 +598,7 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Like user@server</source>
-        <translation type="unfinished"></translation>
+        <translation>Com usuari@servidor</translation>
     </message>
     <message>
         <source>&amp;Connect</source>
@@ -615,24 +636,25 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Nickname</source>
-        <translation type="unfinished">Sobrenom</translation>
+        <translation>Sobrenom</translation>
     </message>
     <message>
         <source>Loaded identity data for %1.</source>
         <comment>%1 is a nickname</comment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Dades d&apos;identitat carregades per a %1.</translation>
     </message>
     <message>
         <source>Saved identity data for %1.</source>
         <comment>%1 is a nickname</comment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Dades d&apos;identitat guardats per a %1.</translation>
     </message>
 </context>
 <context>
     <name>LogModule</name>
     <message>
-        <source>AkariXB started.</source>
-        <translation>AkariXB iniciat.</translation>
+        <source>AkariXB v%1 started.</source>
+        <comment>%1 = Version number</comment>
+        <translation>AkariXB v%1 iniciat.</translation>
     </message>
 </context>
 <context>
@@ -708,7 +730,7 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Report a Bug</source>
-        <translation type="unfinished"></translation>
+        <translation>Informar d&apos;un error</translation>
     </message>
     <message>
         <source>%1 connected.</source>
@@ -720,23 +742,24 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Network error: %1</source>
-        <translation type="unfinished">Error de xarxa: %1</translation>
+        <translation>Error de xarxa: %1</translation>
     </message>
     <message>
         <source>Chats</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Converses</translation>
     </message>
     <message>
         <source>Commands</source>
-        <translation type="unfinished">Ordres</translation>
+        <translation>Ordres</translation>
     </message>
     <message>
         <source>Conversation</source>
+        <translatorcomment>FIXME</translatorcomment>
         <translation type="unfinished">Conversa</translation>
     </message>
     <message>
         <source>Activities</source>
-        <translation type="unfinished">Activitats</translation>
+        <translation>Activitats</translation>
     </message>
     <message>
         <source>AkariXB is Free Software, licensed under the GNU GPL license, and uses some Oxygen icons under LGPL license.</source>
@@ -760,7 +783,7 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Identity</source>
-        <translation type="unfinished">Identitat</translation>
+        <translation>Identitat</translation>
     </message>
     <message>
         <source>Ready.</source>
@@ -780,11 +803,11 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Desconnectat</translation>
     </message>
     <message>
         <source>Connection to the server was lost.</source>
-        <translation type="unfinished">S&apos;ha perdut la connexió amb el servidor.</translation>
+        <translation>S&apos;ha perdut la connexió amb el servidor.</translation>
     </message>
     <message>
         <source>Socket Error</source>
@@ -792,7 +815,7 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>KeepAlive Error</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Error de KeepAlive</translation>
     </message>
     <message>
         <source>XMPP Stream Error</source>
@@ -800,11 +823,11 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>About XMPP</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Sobre XMPP</translation>
     </message>
     <message>
         <source>Quit?</source>
-        <translation type="unfinished"></translation>
+        <translation>Sortir?</translation>
     </message>
     <message>
         <source>Are you sure?</source>
@@ -812,11 +835,15 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Yes, quit AkariXB</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Sí, sortir d&apos;AkariXB</translation>
     </message>
     <message>
         <source>No</source>
-        <translation type="unfinished"></translation>
+        <translation>No</translation>
+    </message>
+    <message>
+        <source>Connection seems stuck. Trying again...</source>
+        <translation>La connexió sembla encallada. Intentant-ho de nou...</translation>
     </message>
 </context>
 <context>
@@ -825,16 +852,21 @@ The reply will be the console output of the program, unless you specify a reply
         <source>Error %1 from %2: %3</source>
         <translation>Error %1 de %2: %3</translation>
     </message>
+    <message>
+        <source>Headline from %1</source>
+        <translatorcomment>Psi, Gajim...</translatorcomment>
+        <translation type="unfinished">Titular de %1</translation>
+    </message>
 </context>
 <context>
     <name>RoomModule</name>
     <message>
         <source>Add &amp;New Room</source>
-        <translation type="unfinished"></translation>
+        <translation>Afegir &amp;nova sala</translation>
     </message>
     <message>
         <source>&amp;Remove Room</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Treure sala</translation>
     </message>
     <message>
         <source>Room address</source>
@@ -842,12 +874,12 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Nickname</source>
-        <translatorcomment>meh...</translatorcomment>
-        <translation type="unfinished">Sobrenom</translation>
+        <translation>Sobrenom</translation>
     </message>
     <message>
         <source>Autojoin</source>
-        <translation type="unfinished">Auto-entrar</translation>
+        <translatorcomment>Meh...</translatorcomment>
+        <translation>Auto-entrar</translation>
     </message>
     <message>
         <source>Join</source>
@@ -859,7 +891,7 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Select a room from the list above</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Selecciona una sala de la llista de la part superior</translation>
     </message>
     <message>
         <source>Room Details</source>
@@ -867,6 +899,7 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>%1 as %2</source>
+        <translatorcomment>FIXME: meh...</translatorcomment>
         <translation type="unfinished">%1 com a %2</translation>
     </message>
     <message>
@@ -875,19 +908,19 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Room address is not valid.</source>
-        <translation type="unfinished"></translation>
+        <translation>L&apos;adreça de la sala no és vàlida.</translation>
     </message>
     <message>
         <source>Nickname is not valid.</source>
-        <translation type="unfinished"></translation>
+        <translation>El sobrenom no és vàlid.</translation>
     </message>
     <message>
         <source>New Room</source>
-        <translation type="unfinished">Sala nova</translation>
+        <translation>Sala nova</translation>
     </message>
     <message>
         <source>Leaving room %1...</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Sortint de la sala %1...</translation>
     </message>
     <message>
         <source>&amp;Edit</source>
@@ -899,7 +932,7 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <source>Joining room %1...</source>
-        <translation type="unfinished">Entrant a al sala %1...</translation>
+        <translation>Entrant a al sala %1...</translation>
     </message>
     <message>
         <source>Password, if needed</source>
