@@ -92,7 +92,7 @@
     </message>
     <message>
         <source>Maximum Times Per Day</source>
-        <translation type="unfinished">Máximo de veces por día</translation>
+        <translation>Máximo de veces por día</translation>
     </message>
     <message>
         <source>Probability</source>
@@ -100,11 +100,11 @@
     </message>
     <message>
         <source>Time Range</source>
-        <translation type="unfinished">Rango de horas</translation>
+        <translation>Rango de horas</translation>
     </message>
     <message>
         <source>Date Range</source>
-        <translation type="unfinished">Rango de fechas</translation>
+        <translation>Rango de fechas</translation>
     </message>
     <message>
         <source>Duration</source>
@@ -136,7 +136,7 @@
     </message>
     <message>
         <source>&amp;Sync Activities</source>
-        <translation type="unfinished">&amp;Sincronizar actividades</translation>
+        <translation>&amp;Sincronizar actividades</translation>
     </message>
     <message>
         <source>&amp;Remove Activity</source>
@@ -158,11 +158,6 @@
         <source>Error: There is already an activity in the list with this name.</source>
         <translation>Error: Ya hay una actividad en la lista con este nombre.</translation>
     </message>
-    <message>
-        <source>Specific JIDs</source>
-        <translatorcomment>FIXME: Habría que investigar si JID es masculino (IDentificador Jabber) o femenino (IDentificación Jabber)</translatorcomment>
-        <translation type="obsolete">JIDs específicos</translation>
-    </message>
     <message>
         <source>List of room or user addresses, separated by space</source>
         <translation>Lista de direcciones de salas o de usuarios, separadas por espacios</translation>
@@ -208,7 +203,7 @@
     </message>
     <message>
         <source>A new chat was started by %1.</source>
-        <translation type="unfinished">%1 ha iniciado una nueva conversación.</translation>
+        <translation>%1 ha iniciado una nueva conversación.</translation>
     </message>
 </context>
 <context>
@@ -219,11 +214,12 @@
     </message>
     <message>
         <source>Kicked from the room!</source>
-        <translation type="unfinished">¡Expulsado de la sala!</translation>
+        <translation>¡Expulsado de la sala!</translation>
     </message>
     <message>
         <source>Joined room %1, as %2.</source>
-        <translation>Se ha entrado a la sala %1, como %2.</translation>
+        <translatorcomment>Jan: no me convence esta string, creo que cambiaré la original para la v0.7</translatorcomment>
+        <translation type="unfinished">Se ha entrado a la sala %1, como %2.</translation>
     </message>
     <message>
         <source>Left room %1.</source>
@@ -250,7 +246,7 @@
     </message>
     <message>
         <source>Command gave no output text.</source>
-        <translation type="unfinished">El comando no ha dado ningún texto de salida.</translation>
+        <translation>El comando no ha dado ningún texto de salida.</translation>
     </message>
     <message>
         <source>I don&apos;t have help about: %1</source>
@@ -266,15 +262,11 @@
     </message>
     <message>
         <source>Command %1 requested without the right access level.</source>
-        <translation type="unfinished">Se ha solicitado el comando %1 sin el nivel de acceso adecuado.</translation>
-    </message>
-    <message>
-        <source>I need a parameter for the query.</source>
-        <translation type="vanished">Necesito un parámetro para la consulta.</translation>
+        <translation>Se ha solicitado el comando %1 sin el nivel de acceso adecuado.</translation>
     </message>
     <message>
         <source>I don&apos;t have a match for %1</source>
-        <translation type="unfinished">No tengo ninguna coincidencia para %1</translation>
+        <translation>No tengo ninguna coincidencia para %1</translation>
     </message>
     <message>
         <source>This command is an alias to itself!</source>
@@ -290,7 +282,7 @@
     </message>
     <message>
         <source>Started detached program successfully.</source>
-        <translation type="unfinished">Se ha iniciado el programa independiente correctamente.</translation>
+        <translation>Se ha iniciado correctamente el programa, de forma independiente.</translation>
     </message>
     <message>
         <source>I need a parameter for the query:</source>
@@ -333,7 +325,7 @@
     </message>
     <message>
         <source>&amp;Sync Commands</source>
-        <translation type="unfinished">&amp;Sincronizar comandos</translation>
+        <translation>&amp;Sincronizar comandos</translation>
     </message>
     <message>
         <source>&amp;Remove Command</source>
@@ -404,11 +396,6 @@
         <source>Command exists</source>
         <translation>El comando ya existe</translation>
     </message>
-    <message>
-        <source>Error: There is already a command in the list with this trigger.</source>
-        <translatorcomment>FIXME</translatorcomment>
-        <translation type="obsolete">Error: Ya hay un comando en la lista con este &apos;trigger&apos;.</translation>
-    </message>
     <message>
         <source>Just enter a single sentence.</source>
         <translation>Introduce una única frase.</translation>
@@ -433,21 +420,10 @@ La codificación del archivo debe ser UTF-8.</translation>
         <source>Add keywords to the list, then enter the corresponding definition for each keyword on the other side.</source>
         <translation>Añade palabras clave a la lista, luego introduce la definición correspondiente para cada palabra clave en el otro lado.</translation>
     </message>
-    <message>
-        <source>Enter a command to be run, with any needed parameters.
-The reply will be the console output of the program, unless you specify an output pattern, and don&apos;t include the %output% variable somewhere in it.</source>
-        <comment>Don&apos;t translate %output%!</comment>
-        <translation type="vanished">Introduce un comando para ejecutar, con los parámetros que pueda necesitar.
-La respuesta será la salida en consola del programa, a menos que especifiques un patrón de salida, y no incluyas la variable %output% en algún lugar del mismo.</translation>
-    </message>
     <message>
         <source>Enter the original command that should be run when this alias is used.</source>
         <translation>Introduce el comando original que se debe ejecutar cuando se use este alias.</translation>
     </message>
-    <message>
-        <source>Output Pattern</source>
-        <translation type="obsolete">Patrón de salida</translation>
-    </message>
     <message>
         <source>Private Reply</source>
         <translation>Respuesta en privado</translation>
@@ -474,21 +450,9 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
             <numerusform>Se han guardado %Ln comandos.</numerusform>
         </translation>
     </message>
-    <message>
-        <source>The trigger word, without the prefix</source>
-        <translatorcomment>FIXME</translatorcomment>
-        <translation type="obsolete">La palabra &apos;trigger&apos;, sin el prefijo</translation>
-    </message>
-    <message>
-        <source>Enter a system command line to be run, with any needed parameters.
-The reply will be the console output of the program, unless you specify an output pattern, and don&apos;t include the %output% variable somewhere in it.</source>
-        <comment>Don&apos;t translate %output%!</comment>
-        <translation type="obsolete">Introduce una línea de comando del sistema para ejecutar, con los parámetros que pueda necesitar.
-La respuesta será la salida en consola del programa, a menos que especifiques un patrón de salida, y no incluyas la variable %output% en algún lugar del mismo.</translation>
-    </message>
     <message>
         <source>If the program you launch will take a long time to finish (like a GUI), you need to select the option to launch it independently, but then it will not be possible to use the program output as the reply for the command.</source>
-        <translation type="unfinished">Si el programa que lanzas va a tardar mucho tiempo en terminar (como un GUI), debes seleccionar la opción de lanzarlo independientemente, pero entonces no será posible usar la salida del programa como respuesta para el comando.</translation>
+        <translation>Si el programa que lanzas va a tardar mucho tiempo en terminar (como un GUI), debes seleccionar la opción de lanzarlo independientemente, pero entonces no será posible usar la salida del programa como respuesta para el comando.</translation>
     </message>
     <message>
         <source>Wait for the program to finish</source>
@@ -496,31 +460,56 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>Launch the program independently</source>
-        <translation type="unfinished">Lanzar el programa independientemente</translation>
-    </message>
-    <message>
-        <source>Optional, like: [RESULT]</source>
-        <translation>Opcional, como: [RESULTADO]</translation>
+        <translation>Lanzar el programa de forma independiente</translation>
     </message>
     <message>
         <source>The name, without the prefix</source>
-        <translation type="unfinished">El nombre, sin el prefijo</translation>
+        <translation>El nombre, sin el prefijo</translation>
     </message>
     <message>
         <source>Error: There is already a command in the list with this name.</source>
-        <translation type="unfinished">Error: Ya hay un comando en la lista con este nombre.</translation>
+        <translation>Error: Ya hay un comando en la lista con este nombre.</translation>
     </message>
     <message>
         <source>Enter a system command line to be run, with any needed parameters.
 The reply will be the console output of the program, unless you specify a reply pattern, and don&apos;t include the %output% variable somewhere in it.</source>
         <comment>Don&apos;t translate %output%!</comment>
-        <translation type="unfinished">Introduce una línea de comando del sistema para ejecutar, con los parámetros que pueda necesitar.
+        <translation>Introduce una línea de comando del sistema para ejecutar, con los parámetros que pueda necesitar.
 La respuesta será la salida en consola del programa, a menos que especifiques un patrón de respuesta, y no incluyas la variable %output% en algún lugar del mismo.</translation>
     </message>
     <message>
         <source>Reply Pattern</source>
         <translation>Patrón de respuesta</translation>
     </message>
+    <message>
+        <source>Set an optional reply pattern</source>
+        <translation type="unfinished">Establece un patrón de respuesta opcional</translation>
+    </message>
+    <message>
+        <source>With a reply pattern you can make any possible reply to a command fit into a predefined structure, like having a specific symbol at the start or the end of the reply, or always start the reply with a fixed word.</source>
+        <translation type="unfinished">Con un patrón de respuesta, puedes hacer que cualquier respuesta posible encaje en una estructura predefinida, como tener un símbolo específico al principio o al final de la respuesta, o empezar siempre la respuesta con una palabra fija.</translation>
+    </message>
+    <message>
+        <source>You can insert variables like %user%, %params%, %output%, %line% and %smiley%.</source>
+        <comment>Do not translate the words between % symbols</comment>
+        <translation>Puedes insertar variables como %user%, %params%, %output%, %line% y %smiley%.</translation>
+    </message>
+    <message>
+        <source>Usually, you will want to have the %output% variable somewhere in the pattern.</source>
+        <comment>Do not translate %output%</comment>
+        <translation type="unfinished">Normalmente, te interesará tener la variable %output% en algún lugar del patrón.</translation>
+    </message>
+    <message>
+        <source>If you don&apos;t set a reply pattern, replies in chatrooms will use the default pattern, %user%: %output%.</source>
+        <comment>Do not translate %user% or %output%</comment>
+        <translatorcomment>Jan: Quizá podríamos ampliar la versión traducida con una aclaración en castellano entre paréntesis, tipo: (Usuario: Respuesta).</translatorcomment>
+        <translation type="unfinished">Si no estableces un patrón de respuesta, las respuestas en salas de charla usarán el patrón predefinido, %user%: %output%.</translation>
+    </message>
+    <message>
+        <source>Example: [RESULT] &gt; %output%</source>
+        <comment>Do not translate %output%</comment>
+        <translation type="unfinished">Ejemplo: [RESULTADO] &gt; %output%</translation>
+    </message>
 </context>
 <context>
     <name>ConfigDialog</name>
@@ -571,7 +560,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>Connection timeout</source>
-        <translation type="unfinished">Tiempo máximo de espera de la conexión</translation>
+        <translation>Tiempo máximo de espera de la conexión</translation>
     </message>
     <message>
         <source>Notify disconnection</source>
@@ -579,7 +568,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>Connection ping interval</source>
-        <translation type="unfinished">Intervalo de ping de la conexión</translation>
+        <translation>Intervalo de ping de la conexión</translation>
     </message>
 </context>
 <context>
@@ -668,8 +657,9 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
 <context>
     <name>LogModule</name>
     <message>
-        <source>AkariXB started.</source>
-        <translation>AkariXB iniciado.</translation>
+        <source>AkariXB v%1 started.</source>
+        <comment>%1 = Version number</comment>
+        <translation>AkariXB v%1 iniciado.</translation>
     </message>
 </context>
 <context>
@@ -846,7 +836,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>Are you sure?</source>
-        <translation type="unfinished">¿Seguro?</translation>
+        <translation>¿Seguro?</translation>
     </message>
     <message>
         <source>Yes, quit AkariXB</source>
@@ -856,6 +846,10 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>No</source>
         <translation>No</translation>
     </message>
+    <message>
+        <source>Connection seems stuck. Trying again...</source>
+        <translation>La conexión parece haberse atascado. Intentándolo de nuevo...</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -863,6 +857,11 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
         <source>Error %1 from %2: %3</source>
         <translation>Error %1 de %2: %3</translation>
     </message>
+    <message>
+        <source>Headline from %1</source>
+        <translatorcomment>FIXME? Psi usa &quot;titular&quot;; comprobar con Swift/Gajim/otros...</translatorcomment>
+        <translation type="unfinished">Titular de %1</translation>
+    </message>
 </context>
 <context>
     <name>RoomModule</name>
@@ -884,7 +883,8 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>Autojoin</source>
-        <translation type="unfinished">Auto-entrar</translation>
+        <translatorcomment>Meh...</translatorcomment>
+        <translation>Auto-entrar</translation>
     </message>
     <message>
         <source>Join</source>
@@ -904,6 +904,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>%1 as %2</source>
+        <translatorcomment>FIXME: meh...</translatorcomment>
         <translation type="unfinished">%1 como %2</translation>
     </message>
     <message>
@@ -936,7 +937,7 @@ La respuesta será la salida en consola del programa, a menos que especifiques u
     </message>
     <message>
         <source>Joining room %1...</source>
-        <translation>Entrando a la sala %1...</translation>
+        <translation>Entrant a la sala %1...</translation>
     </message>
     <message>
         <source>Password, if needed</source>
